window.Gleam.initSearch([{"doc":"dotenv_conf","title":"dotenv_conf","content":"# dotenv_conf\n\nEasy configurations from environment variables and .env files.\n\n[![Package Version](https://img.shields.io/hexpm/v/dotenv_conf)](https://hex.pm/packages/dotenv_conf)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/dotenv_conf/)\n\ndotenv_conf uses environment variables by default, and if they do not exist, look at whether the value is defined in a .env file.  \nThat simplifies the dev process while allowing [12-factor configuration](https://12factor.net/config) for other environments.\n\n## Quick start\n\n```sh\ngleam add dotenv_conf\n```\n```gleam\nimport dotenv_conf\n\ntype Context {\n  Context(\n    database_path: String,\n    application_port: Int\n  )\n}\n\npub fn main() {\n  use file &lt;- dotenv_conf.read_file(&quot;.env&quot;)\n  let context = Context(\n    database_path: dotenv_conf.read_string_or(&quot;DB_PATH&quot;, file, &quot;[memory]&quot;),\n    application_port: dotenv_conf.read_int_or(&quot;PORT&quot;, file, 8000)\n  )\n\n  // use the context after that\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/dotenv_conf&gt;.\n\n## Roadmap\n\n- [ ] Support comments in .env files\n- [ ] Ignore blank lines in the middle of a file instead of failing\n- [ ] Quotes\n- [ ] Interpolation\n- [ ] Multi-line values\n- [ ] Escape sequences\n","url":"index.html"},{"doc":"dotenv_conf","title":"EnvFile","content":"pub type EnvFile =\n  Result(Dict(String, String), EnvFileError)\n `EnvFile` represents the environment file result.  \n When the file is read correctly, it contains `Ok(Dict(String, String))`\n with all the parsed values. If an error occurs, it contains\n `Error(EnvFileError)`.\n\n\nSynonyms:\ndotenv_conf.EnvFile\ndotenv_conf EnvFile","url":"dotenv_conf.html#EnvFile"},{"doc":"dotenv_conf","title":"EnvFileError","content":"pub type EnvFileError {\n  MissingFile\n  InvalidFile\n  FileError\n  BadConfig\n  MissingVar\n}\n `EnvFileError` is an enumeration of the possible errors when dealing with\n the .env file.\n\n - `MissingFile`: the file is not found at the provided path.\n - `InvalidFile`: the file is not correct (likely is a directory or special).\n - `FileError`: an error occured when reading the file.\n - `BadConfig`: the format of the file is not correct.\n - `MissingVar`: the config variable does not exist.\n\nMissingFile\n\n\nInvalidFile\n\n\nFileError\n\n\nBadConfig\n\n\nMissingVar\n\n\nSynonyms:\ndotenv_conf.EnvFileError\ndotenv_conf EnvFileError","url":"dotenv_conf.html#EnvFileError"},{"doc":"dotenv_conf","title":"read_file","content":"pub fn read_file(\n  path: String,\n  then: fn(Result(Dict(String, String), EnvFileError)) -&gt; a,\n) -&gt; a\n Reads the .env file at the given `path`. It is meant to be used as a use\n expression.\n\n ## Example\n\n \n use file &lt;- read_file(&quot;.env&quot;)\n let username = read_string_or(&quot;USER&quot;, file, &quot;admin&quot;)\n \n\nSynonyms:\ndotenv_conf.read_file\ndotenv_conf read_file","url":"dotenv_conf.html#read_file"},{"doc":"dotenv_conf","title":"read_float_or","content":"pub fn read_float_or(\n  name: String,\n  from_file: Result(Dict(String, String), EnvFileError),\n  default: Float,\n) -&gt; Float\n Reads the config float with the given `name`, first from the environment\n variables and, if not found, from the EnvFile read using `read_file`. If\n neither works, the given `default` value is used.\n\nSynonyms:\ndotenv_conf.read_float_or\ndotenv_conf read_float_or","url":"dotenv_conf.html#read_float_or"},{"doc":"dotenv_conf","title":"read_int_or","content":"pub fn read_int_or(\n  name: String,\n  from_file: Result(Dict(String, String), EnvFileError),\n  default: Int,\n) -&gt; Int\n Reads the config integer with the given `name`, first from the environment\n variables and, if not found, from the EnvFile read using `read_file`. If\n neither works, the given `default` value is used.\n\nSynonyms:\ndotenv_conf.read_int_or\ndotenv_conf read_int_or","url":"dotenv_conf.html#read_int_or"},{"doc":"dotenv_conf","title":"read_string","content":"pub fn read_string(\n  name: String,\n  from_file: Result(Dict(String, String), EnvFileError),\n) -&gt; Result(String, EnvFileError)\n Reads the config string with the given `name`. If it is not found in the\n environment variables, the EnvFile read using `read_file` is used.\n If there was an error reading the file or the key is not found in the file\n either, an `Error(EnvFileError)` is returned.\n\n This function can be used to implement custom config types, otherwise\n `read_&lt;type&gt;_or` is preferrable.\n\nSynonyms:\ndotenv_conf.read_string\ndotenv_conf read_string","url":"dotenv_conf.html#read_string"},{"doc":"dotenv_conf","title":"read_string_or","content":"pub fn read_string_or(\n  name: String,\n  from_file: Result(Dict(String, String), EnvFileError),\n  default: String,\n) -&gt; String\n Reads the config string with the given `name`, first from the environment\n variables and, if not found, from the EnvFile read using `read_file`. If\n neither works, the given `default` value is used.\n\nSynonyms:\ndotenv_conf.read_string_or\ndotenv_conf read_string_or","url":"dotenv_conf.html#read_string_or"},{"doc":"dotenv_conf","title":"dotenv_conf","content":" The `dotenv_conf` is made to support both configurations via environment\n variables (via `envoy`) and .env files.\n\n .env files are read using `read_file`, then passed to the specific `read_`\n functions, to avoid reading the file multiple times.","url":"dotenv_conf.html"}]);